@@ -1,5 +1,7 @@
 # Per group:
-expected_hessian_Ising_group <- function(omega,tau,beta,responses,nobs,...){
+expected_hessian_Ising_group <- function(omega,tau,beta,responses,nobs,min_sum,...){
+  
+  # FIXME: Hi 2020 Sacha, this is 2023 Sacha. Why is this in R? Why not in C++?
   
   # Graph and thresholds:
   thresholds <- as.vector(tau)
@@ -9,6 +11,13 @@ expected_hessian_Ising_group <- function(omega,tau,beta,responses,nobs,...){
   # Compute likelihood table:
   LikTable <- IsingSampler::IsingLikelihood(graph,thresholds,beta,responses,potential=TRUE)
   states <- as.matrix(LikTable[,-1])
+  
+  # Cut out states if needed for min_sum:
+  if (min_sum > -Inf){
+    LikTable <- LikTable[rowSums(states) >= min_sum,]
+    states <- states[rowSums(states) >= min_sum, ]
+  }
+  
   Z <- sum(LikTable$Potential)
   probabilities <- LikTable$Potential / Z
   
