@@ -1,10 +1,19 @@
 # Implied model for precision. Requires appropriate model matrices:
 implied_lvm <- function(model, all = FALSE){
-
-  x <- formModelMatrices(model)
+  if (model@cpp){
+    x <- formModelMatrices_cpp(model)
+  } else {
+    x <- formModelMatrices(model)  
+  }
   
-  x <- impliedcovstructures(x,"zeta",type = model@types$latent, all = all)
-  x <- impliedcovstructures(x,"epsilon",type = model@types$residual, all = all)
+  if (model@cpp){
+    x <- impliedcovstructures_cpp(x,"zeta",type = model@types$latent, all = all)
+    x <- impliedcovstructures_cpp(x,"epsilon",type = model@types$residual, all = all)
+  } else {
+    x <- impliedcovstructures(x,"zeta",type = model@types$latent, all = all)
+    x <- impliedcovstructures(x,"epsilon",type = model@types$residual, all = all)
+  }
+
 
     # For each group:
   nGroup <- length(x)
@@ -14,7 +23,7 @@ implied_lvm <- function(model, all = FALSE){
 
     
     # Matrices I need in every model framework when estimating:
-      BetaStar <- as(solve(Diagonal(nrow(x[[g]]$beta)) - x[[g]]$beta),"Matrix")
+      BetaStar <- as.matrix(solve(Diagonal(nrow(x[[g]]$beta)) - x[[g]]$beta))
       Lambda_BetaStar <- x[[g]]$lambda %*%  BetaStar 
       Betasta_sigmaZeta <- BetaStar %*% x[[g]]$sigma_zeta
       tBetakronBeta <- t(BetaStar) %x% BetaStar      
@@ -41,6 +50,11 @@ implied_lvm <- function(model, all = FALSE){
       
       # FIXME: forcing symmetric, but not sure why this is needed...
       # x[[g]]$kappa <- 0.5*(x[[g]]$kappa + t(x[[g]]$kappa))
+      
+      # # Kappa, sigma and mu never sparse:
+      # x[[g]]$mu <- as.matrix(x[[g]]$mu)
+      # x[[g]]$kappa <- as.matrix(x[[g]]$kappa)
+      # x[[g]]$sigma <- as.matrix(x[[g]]$sigma)
   }
   
   return(x)
