@@ -54,7 +54,7 @@ lvm <- function(
   if (rawts){
     warning("'rawts' is only included for testing purposes. Please do not use!")
   }
-  
+
   # Type:
   latent <- match.arg(latent)
   residual <- match.arg(residual)
@@ -350,11 +350,11 @@ lvm <- function(
     L_eta = psychonetrics::eliminationMatrix(nLatent), # Elinimation matrix
     Dstar = psychonetrics::duplicationMatrix(nNode,diag = FALSE), # Strict duplicaton matrix
     Dstar_eta = psychonetrics::duplicationMatrix(nLatent,diag = FALSE), # Strict duplicaton matrix
-    In = as(diag(nNode),"dgCMatrix"), # Identity of dim n
-    Inlatent = as(diag(nLatent),"dgCMatrix"),
-    C = as(lavaan::lav_matrix_commutation(nNode, nLatent),"dgCMatrix"),
-    Cbeta = as(lavaan::lav_matrix_commutation(nLatent, nLatent),"dgCMatrix"),
-    C_chol = as(lavaan::lav_matrix_commutation(nNode, nNode),"dgCMatrix"),
+    In = as(diag(nNode),"dMatrix"), # Identity of dim n
+    Inlatent = as(diag(nLatent),"dMatrix"),
+    C = as(lavaan::lav_matrix_commutation(nNode, nLatent),"dMatrix"),
+    Cbeta = as(lavaan::lav_matrix_commutation(nLatent, nLatent),"dMatrix"),
+    C_chol = as(lavaan::lav_matrix_commutation(nNode, nNode),"dMatrix"),
     A = psychonetrics::diagonalizationMatrix(nNode),
     Aeta = psychonetrics::diagonalizationMatrix(nLatent)
   )
